<?php

// Functions to do the needed web service requests
// Note that all needed web services are sent from this directory
// The functions here should throw up to their callers, just like
// the old functions in model.
//
// use Composer autoloader, so we don't have to require Guzzle PHP files
require '../vendor/autoload.php';
$httpClient = new \GuzzleHttp\Client();
// We are assuming the server site is a sibling of this site on
// the webserver file system, not the usual setup but convenient for us.
$dirs = explode(DIRECTORY_SEPARATOR, __DIR__);
array_pop($dirs); // remove last element (this dir)
array_pop($dirs); // remove this site project dir
$project_parent = implode('/', $dirs) . '/';
$doc_root = filter_input(INPUT_SERVER, 'DOCUMENT_ROOT');
// parent_path is the part of $project_parent past $doc_root
$parent_path = substr($project_parent, strlen($doc_root));
// base_url of the server site is child of this site's parent:
$base_url = "http://localhost" . $parent_path . 'ch05_gs_server/api/';

// POST product and get back location (URL of new product)
function rest_post_product($httpClient, $base_url, $product, $category_name) {
    $url = $base_url . "/categories/$category_name/products";
    // Guzzle does the json_encode for us--
    $response = $httpClient->request('POST', $url, ['json' => $product]);
    $location = $response->getHeader('Location');
    error_log("client rest_post_prduct: location = " . print_r($location, true));
    return $location[0];  // first entry in array is string Location URL
}

function rest_get_products_by_category($httpClient, $base_url, $cat_name) {
    $url = $base_url . "categories/$cat_name/products";
    // echo "url = $url, cat_name = $cat_name";
    $response = $httpClient->get($url);
    $productsJson = $response->getBody()->getContents();
    //     echo 'JSON: ' . $productsJson;

    $products = json_decode($productsJson, true);
    //    echo '<pre>' . print_r($products, true) . '</pre>';
    // error_log('products After json_decode:');
    // error_log(print_r($products, true));
    return $products;
}

function rest_get_product($httpClient, $base_url, $productID, $categoryName) {
    $url = $base_url . "categories/$categoryName/products/$productID";
    $response = $httpClient->get($url);
    $productJson = $response->getBody()->getContents();  // as StreamInterface, then string
    //   echo $productJson;
    $product = json_decode($productJson, true);
    //   echo '<pre>' . print_r($product, true) . '</pre>';
    return $product;
}

function rest_delete_product($httpClient, $base_url, $productID, $categoryName) {
    $url = $base_url . "categories/$categoryName/products/$productID";
    $response = $httpClient->delete($url);
    return;
}

function rest_get_categories($httpClient, $base_url) {
    // echo 'rest_get_categories ';
    $url = $base_url . 'categories';
    // echo 'url = ' . $url;
    $response = $httpClient->get($url);
    $categoriesJson = $response->getBody()->getContents();  // as StreamInterface, then string
    $categories = json_decode($categoriesJson, true);
    // error_log('client: categories After json_decode:');
    // error_log(print_r($categories, true));
    return $categories;
}
